/*
 * This file is part of MiToBo, the Microscope Image Analysis Toolbox.
 *
 * Copyright (C) 2010
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Fore more information on MiToBo, visit
 *
 *    http://www.informatik.uni-halle.de/mitobo/
 *
 */

package cmdTools.development;

import de.unihalle.informatik.MiToBo.operator.*;

/**
 * @author Stefan Posch
 */
public class GenerateGetterSetter {

	public static void main(String [] args) {
		System.out.print(" " +
				"<MiToBo>  Copyright (C) 2010  \n" +
				"This program comes with ABSOLUTELY NO WARRANTY; \n" +
				"This is free software, and you are welcome to redistribute it\n" +
				"under the terms of the GNU General Public License.\n\n\n");
		
		if ( args.length != 1 ) {
			System.err.println( "usage: GenerateGetterSetter classname");
			System.exit(-1);
		}

		MTBOperator op = null;
		try {
			System.out.println( Class.forName( args[0]));
			System.out.println();

			op = (MTBOperator)(Class.forName( args[0]).newInstance());
		} catch (Exception e) {
			System.err.println( "GenerateGetterSetter: cannot instantiate " + args[0]);
			e.printStackTrace();
		}


		try {
	    	String[] parameterNames = op.getParameterNames();
        	for ( int n=0 ; n < op.getNumParameters() ; n++ )
            	System.out.println( generateAccessFunction( op.getParameterDescriptor( parameterNames[n]), "Parameter"));

	    	String[] inputNames = op.getInputNames();
        	for ( int n=0 ; n < op.getNumInputs() ; n++ )
            	System.out.println( generateAccessFunction( op.getInputDescriptor( inputNames[n]), "Input"));

	    	String[] outputNames = op.getOutputNames();
        	for ( int n=0 ; n < op.getNumOutputs() ; n++ )
            	System.out.println( generateAccessFunction( op.getOutputDescriptor( outputNames[n]), "Output"));

	    	String[] supplementalNames = op.getSupplementalNames();
        	for ( int n=0 ; n < op.getNumSupplementals() ; n++ )
            	System.out.println( generateAccessFunction( op.getSupplementalDescriptor( supplementalNames[n]), "Supplemental"));
		} catch (Exception e) {
			System.err.println( "GenerateGetterSetter: got excpetion");
			e.printStackTrace();
		}

	}
	public static String generateAccessFunction( MTBOpArgumentDescriptor descriptor,
			String argType) {
		return new String(  "/** Get value of " + argType + " argument " + descriptor.name + ".\n" +
							"  * @return value of " + descriptor.name + "\n" +
							"  */\n" +
							"public " + descriptor.myclass.getName() +
							" get" + Character.toUpperCase( descriptor.name.charAt(0)) + 
							descriptor.name.substring(1) +
							"()" + " throws MTBOperatorException {\n\treturn (" + descriptor.myclass.getName() + ")" +
							"(this.get" + argType + "(\"" +descriptor.name + "\"));\n}\n" +

							"/** Set value of " + argType + " argument " + descriptor.name + ".\n" +
							"  * @param value New value for " + descriptor.name + "\n" +
							"  */\n" +
							"public void" +
							" set" + Character.toUpperCase( descriptor.name.charAt(0)) + 
							descriptor.name.substring(1) +
							"( " + descriptor.myclass.getName() + " value )" + 
							" throws MTBOperatorException {\n\t" + 
							" this.set" + argType + "(\"" +descriptor.name + "\", value);\n}\n" 
					);
	}

}
