/*
 * This file is part of MiToBo, the Microscope Image Analysis Toolbox.
 *
 * Copyright (C) 2010
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Fore more information on MiToBo, visit
 *
 *    http://www.informatik.uni-halle.de/mitobo/
 *
 */

package de.unihalle.informatik.MiToBo.datatypes;

import de.unihalle.informatik.MiToBo.operator.*;

/**
 * A set of double values, stored in an double array object to be used as input
 * or output to MTB operators.
 * 
 * @modified Sep 27, 2010
 * 
 * @author Birgit Möller
 */
public class MTBDoubleArray1DData extends MTBData {
		/**
		 * 1D double array to store the data.
		 */
		private Double[] array;

		/**
		 * Construct a set of double values from the given array.
		 * 
		 * @param a
		 *          array with double values
		 */
		public MTBDoubleArray1DData(Double[] a) {
				this.array = a;
		}

		/**
		 * Construct an empty set of double values with given size.
		 * 
		 * @param size
		 *          array size
		 */
		public MTBDoubleArray1DData(int size) {
				this.array = new Double[size];
				for (int i = 0; i < size; ++i)
						this.array[i] = null;
		}

		/**
		 * Returns the MTBDoubleArray1DData object.
		 * 
		 * @return Set of double values.
		 */
		public Double[] getArray() {
				return this.array;
		}

		/**
		 * Set the double values of these object.
		 * 
		 * @param a
		 *          double values to set
		 */
		public void setArray(Double[] a) {
				this.array = a;
		}

		/**
		 * Get double value of the array data at the given position.
		 * 
		 * @param i
		 *          index of the double value
		 * @return Double value at i-th position of the array data.
		 */
		public Double getValue(int i) {
				return this.array[i];
		}

		/**
		 * Set double value at given position.
		 * 
		 * @param i
		 *          index of the double value to set
		 * @param val
		 *          double value to set at i-th position of the array data
		 */
		public void setValue(int i, Double val) {
				this.array[i] = val;
		}
}
