/*
 * This file is part of MiToBo, the Microscope Image Analysis Toolbox.
 *
 * Copyright (C) 2010
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Fore more information on MiToBo, visit
 *
 *    http://www.informatik.uni-halle.de/mitobo/
 *
 */

package de.unihalle.informatik.MiToBo.datatypes;

import de.unihalle.informatik.MiToBo.operator.*;

/**
 * An array to be used as input or output to MTB operators containing arbitrary
 * java objects.
 * 
 * @modified Sep 29, 2010
 * 
 * @author Birgit Möller
 */
public class MTBObjectArray1DData extends MTBData {
		/**
		 * 1D array to store the objects.
		 */
		private Object[] array;

		/**
		 * Construct a new data array from the given array of objects.
		 * 
		 * @param a
		 *          array data
		 */
		public MTBObjectArray1DData(Object[] a) {
				this.array = a;
		}

		/**
		 * Construct a new empty data array with given size.
		 * 
		 * @param size
		 *          array data size
		 */
		public MTBObjectArray1DData(int size) {
				this.array = new Object[size];
				for (int i = 0; i < size; ++i)
						this.array[i] = null;
		}

		/**
		 * Return the array data.
		 * 
		 * @return Array data.
		 */
		public Object[] getArray() {
				return this.array;
		}

		/**
		 * Set the array data.
		 * 
		 * @param a
		 *          array data
		 */
		public void setArray(Object[] a) {
				this.array = a;
		}

		/**
		 * Return an object from the array data at given position.
		 * 
		 * @param i
		 *          position
		 * @return Object at i-th position.
		 */
		public Object getValue(int i) {
				return this.array[i];
		}

		/**
		 * Set an object at a given position of the array data.
		 * 
		 * @param i
		 *          position
		 * @param val
		 *          object to set at i-th position.
		 */
		public void setValue(int x, Object val) {
				this.array[x] = val;
		}

		/**
		 * Return the current size of the array data.
		 * 
		 * @return Containing number of objects in the array data.
		 */
		public int size() {
				return this.array.length;
		}
}
