/*
 * This file is part of MiToBo, the Microscope Image Analysis Toolbox.
 *
 * Copyright (C) 2010
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Fore more information on MiToBo, visit
 *
 *    http://www.informatik.uni-halle.de/mitobo/
 *
 */

package de.unihalle.informatik.MiToBo.operator;

import java.util.*;

import org.apache.xmlbeans.*;
import org.graphdrawing.graphml.xmlns.*;

/** A data port acts as the point where consumers of the corresponding MTBData object mey refer to as origin.
  */

public class MTBDataPort extends MTBPort {
	///** The MTBData object which is represented by this data port.
      //*/
	//private MTBData	data;

	/** The processing history as graphml if any
	 */
 	GraphmlType 	graphmlHistory;

	/** The processing history as xml if any
	 */
	XmlObject 	xmlHistory;

	/** The properties of the underlying MTBData at the time of creation 
	 * of this Dataport
	 */
	private Hashtable<String, String> properties;

	/** Create a data port for a data object.
	 *	
	 * @param	data	data object to be represented by this data port.
	 */
	public MTBDataPort( MTBData data) {
		super( "DataPort");
		this.graphmlHistory = data.getGraphmlHistory();
		this.xmlHistory = data.getXmlHistory();
		this.properties = data.cloneProperties();
	}

	/** Get the grahphml history of this data port
	 *
	 * @return grahphml history of this data port
	 */
	public GraphmlType getGraphmlHistory() {
		return graphmlHistory;
	}

	/** Get the xml history of this data port
	 *
	 * @return xml history of this data port
	 */
	public XmlObject getXmlHistory() {
		return xmlHistory;
	}

    /** Get the keys of all properties set in this data object
     *
     * @return  property keys
     */
    public Enumeration<String> getPropertyKeys() {
        return this.properties.keys();
    }

    /** Set the property with key to new value o.
     *
     * @param key   key of property to set
     * @param o     new value of this property
     */
    public void setProperty( String key, Object o) {
        this.properties.put( key, o.toString());
    }

    /** Get a property value for the given <code>key</code>.
     *
     * @param key   key of property to get
     */
    public String getProperty( String key) {
        return this.properties.get( key);
    }

    /** Get the location property, i.e. property with key location
     */
    public String getLocation() {
        return this.properties.get( "location");
    }


	/** Print some information to System.out.
	 */
	public void print() {
		System.out.println( "MTBPort " + this + //" of type data for " + data +
							" with origin " + getOrigin());
	}

}
