/*
 * This file is part of MiToBo, the Microscope Image Analysis Toolbox.
 *
 * Copyright (C) 2010
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Fore more information on MiToBo, visit
 *
 *    http://www.informatik.uni-halle.de/mitobo/
 *
 */

package de.unihalle.informatik.MiToBo.operator;

/** This class describes the arguments which may be used as inputs, parameters,
 *  outputs, or supplemental arguments for operators.
 *  The descriptions contains a name, the java class, and explanatory string,
 *  a boolean indicating if this argument is requeired or optional, and a default value.
 *  The latter two make oly sense for inputs and parameters and are currently
 *  unused for supplemental arguments.
 */

public class MTBOpArgumentDescriptor {
	public final String name;
	public final Class myclass;
	public final String explanation;
	public final boolean required;
	public final Object defaultValue;

	/* Construct a descriptor 
	 *
	 * @param	name	name of argument
	 * @param	myclass	java class 
	 * @param	explanation explanatory string
	 * @param	required	is this argument required for the operator
	 * @param	Object default value
	 */
	public MTBOpArgumentDescriptor( String name, Class myclass, String explanation,
			boolean required, Object defaultValue) {
		this.name = name;
		this.myclass = myclass;
		this.explanation = explanation;
		this.required = required;
		this.defaultValue = defaultValue;
	}

	/* Print this descriptor to standard out
	 */
	public void print() {
		System.out.println( name + " of type " + myclass.toString() + 
		(required ? " is reqired (" : " is optional (") +
		explanation + " default: " + defaultValue.toString());
		
	}
}
