/*
 * This file is part of MiToBo, the Microscope Image Analysis Toolbox.
 *
 * Copyright (C) 2010
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Fore more information on MiToBo, visit
 *
 *    http://www.informatik.uni-halle.de/mitobo/
 *
 */

package de.unihalle.informatik.MiToBo.operator;

/** This is the abstract super class of all ports which 
 *  act as  proxies to receive or supply MTBData within a processing graph.
 */

abstract public class MTBPort {

	/** Typename of this port. Used only for printing.
	 */
	public final String typeName;

	/** The origin/producer of this port.
	 *  This is used to construct the processing graph.
	 */
	private MTBPort origin;

	/** Construct a port object 
	 *
	 * @param typeName	type of the port as a String
	 */
	public MTBPort(String typeName) {
		this.typeName = new String( typeName);
	}

	/** Get the origin of this port, which is the parent
	 *  in the processing graph.
	 *
	 * @return	origin of this port, i.e. parent in processing graph.
	 */
	public MTBPort getOrigin() {
		return origin;
	}

	/** Set the origin of this port, which is the parent
	 *  in the processing graph.
	 *
	 * @param	p origin of this port, i.e. parent in processing 
	 */
	void setOrigin( MTBPort p) {
		origin = p;
	}

	/** Print some information on System.out
	 */
	public void print() {
		System.out.println( "MTBPort " + this + " of type " + typeName);
	}
}
