/*
 * This file is part of MiToBo, the Microscope Image Analysis Toolbox.
 *
 * Copyright (C) 2010
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Fore more information on MiToBo, visit
 *
 *    http://www.informatik.uni-halle.de/mitobo/
 *
 */

package de.unihalle.informatik.MiToBo.operator;

import java.io.*;

/**
 * Info class which provides MiToBo plugins with functions
 * to get cvs/svn version information 'online'.
 *
 * @author moeller
 */
public class VersionInfo {
	
	/**
	 * Returns the tag of the current checkout, as specified 
	 * in a given info file.
	 * 
	 * @param infofile 	file where to find the tag information
	 *                  (for MiToBo this is usually './share/rev_info.txt'
	 * @return 			tag of checked out version or null if not available
	 */
	public static String getCvsTag(String infofile) {

		InputStream is= null;
	    BufferedReader br= null;
	    String vLine= null;

		// initialize file reader 
	    try { 
	    	is= VersionInfo.class.getResourceAsStream("/" + infofile);
	    	br= new BufferedReader(new InputStreamReader(is));
	    	vLine= br.readLine();
			if (vLine == null) {
				System.err.println("cvs info file is empty...!?");
				return null;
			}
			return vLine;
	    }
	    catch (Exception e) {
//			System.err.println("CvsInfo: Cannot open file '" + infofile + "'... Release unknown!");
			String dummy= "Unknown_Release";
			return dummy;
	    }
	}

	/**
	 * Returns the tag of the current checkout, as specified 
	 * in a given info file.
	 * 
	 * @param infofile 	file where to find the cvs tag information
	 *                  (for MiToBo this is usually './share/cvs_info.txt'
	 * @return 			tag of checked out version or null if not available
	 */
	public static String getCvsTag() {
		return VersionInfo.getCvsTag("rev_info.txt");
	}
}
