/*
 * This file is part of MiToBo, the Microscope Image Analysis Toolbox.
 *
 * Copyright (C) 2010
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Fore more information on MiToBo, visit
 *
 *    http://www.informatik.uni-halle.de/mitobo/
 *
 */

package mtb_morphology;

import de.unihalle.informatik.MiToBo.datatypes.images.MTBImage;
import de.unihalle.informatik.MiToBo.exceptions.*;
import de.unihalle.informatik.MiToBo.morphology.HDomeTransform3D;
import de.unihalle.informatik.MiToBo.operator.*;

import ij.IJ;
import ij.ImagePlus;
import ij.gui.GenericDialog;
import ij.process.ImageProcessor;

public class HDomeTransform_3D extends MTBOperatorPlugInFilter {

	@Override
  protected void collectArguments() throws MTBOperatorException{
        super.collectArguments();

		MTBOpArgumentDescriptor[] inputDescriptors = null; 
		MTBOpArgumentDescriptor[] outputDescriptors = 
			new MTBOpArgumentDescriptor[] {
				new MTBOpArgumentDescriptor("resultImg", MTBImage.class, 
																		"Result image", true, null)
			};
		MTBOpArgumentDescriptor[] parameterDescriptors = 
			new MTBOpArgumentDescriptor[] {
				new MTBOpArgumentDescriptor("h", Double.class, "H parameter", true, null)
			};
		
		MTBOpArgumentDescriptor[] supplementalDescriptors = null;
	
			addDescriptors( parameterDescriptors, inputDescriptors, 
					             outputDescriptors, supplementalDescriptors);
	}

	public HDomeTransform_3D() throws MTBOperatorException {
		// nothing to do here
	}
	
	// ---- PlugInFilter interface implementations
	@Override
	public int setup(String arg0, ImagePlus imgPlus) {
		super.setup(arg0,imgPlus);
		return DOES_8G + DOES_16 + DOES_32;
	}

	@Override
  public void run(ImageProcessor arg0) {		
		double h= 0;
		
		GenericDialog gd = new GenericDialog("Select maximum dome height");
		gd.addNumericField("h", 50, 0);
		gd.showDialog();		
		if (gd.wasOKed()) {
			h = gd.getNextNumber();
			if (h <= 0.0) {
				IJ.showMessage("h must be larger than 0");
				return;
			}
		}
		try {
			this.setInput("inImg", this.mtbInput);
			this.setParameter("h", new Double(h));
			this.runOp( null);	
			((MTBImage)this.getOutput("resultImg")).show();
		} catch (MTBException e) {
			e.printStackTrace();
			IJ.showStatus("MiToBo HDomeTransform 3D operation not successful");
		}
	}

	@Override
	protected void operate() 
		throws MTBOperatorException, MTBProcessingDAGException {
		HDomeTransform3D hdome = 
			new HDomeTransform3D((MTBImage)this.getInput("inImg"),((Double)this.getParameter("h")).doubleValue());
		hdome.runOp( this);
		MTBImage resImg= hdome.getResultImage();
		resImg.setTitle(this.mtbInput.getTitle() + " h-domes (h=" + this.getParameter("h") + ")");
		this.setOutput("resultImg",hdome.getResultImage());
	}				
}
